/**********************************************************************
 *
 * os_process.h -- base class for OS specific calls related to creating 
 *                 process *without* (in the case of Windows) opening a 
 *                 DOS window.  
 *
 *                 Nett effect is OS neutral way to support
 *                 popen() and related functions
 *
 * Copyright (C) 2010  The New Zealand Digital Library Project
 *
 * A component of the Greenstone digital library software
 * from the New Zealand Digital Library Project at the
 * University of Waikato, New Zealand.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *********************************************************************/

#ifndef OS_PROCESS_H
#define OS_PROCESS_H

 #include <stdlib.h>

enum OSProcessPipeMode { uniRead=0, uniWrite=1, biReadWrite=2, noPipe=3 };

class osprocess 
{
  
 public:
  osprocess(char* cmdline);
  osprocess(char* cmdline, OSProcessPipeMode mode);
  virtual ~osprocess();
  
  /*
  virtual bool eop();                  // end of pipe
  virtual bool eop(OSProcessPipeMode); // end of pipe, for designated pipe
  */

  virtual int write(char* buffer, const int buffer_len);
  virtual int read(char* buffer, const int buffer_len);
  
  virtual bool close();
  virtual bool close(OSProcessPipeMode mode);
  
 protected:
  OSProcessPipeMode mode_;
  bool read_pipe_open_;
  bool write_pipe_open_;

};

#endif

